@@ -22,12 +22,13 @@ sns.set(style="darkgrid")
 __author__ = "Dylan Gatlin"
 
 # camera_offsets = np.array([0.0, -50.2985, -41.05837499999998,
-                        #    11.466562500000009, 52.425531914893625, 0.0])
+#    11.466562500000009, 52.425531914893625, 0.0])
 camera_offsets = np.array([-1.8474999999999977, -52.08291666666667,
                            -111.43416666666663, 0.0,
                            35.64791666666667, 54.41166666666667])
 camera_shifts = np.array([0., 0., +0.05, 0., -0.02])
 
+
 def build_filt(obj_arr: np.ndarray):
     ecc = np.sqrt(obj_arr['a']**2 - obj_arr['b']**2) / obj_arr['a']
     # print(np.percentile(ecc, 75))
@@ -326,7 +327,7 @@ class GFASet:
             fig.savefig(plot_file, dpi=100)
         return fig
 
-    def init_continuous_plot(self, window="0-15"):
+    def init_continuous_plot(self, window="0-15", ignore=[]):
         low, high = window.split("-")
         n_images = int(high) - int(low)
         today = sjd.sjd()
@@ -342,6 +343,8 @@ class GFASet:
             current_num = int(fil.name.split("gfa4n-")[-1].split(".fits")[0])
             latest = max(latest, current_num)
         for im_num in tqdm.tqdm(range(latest - n_images, latest + 1)):
+            if im_num in ignore:
+                continue
             im_ps = []
             for n in self.gfas:
                 p = get_img_path(today, n, im_num)
@@ -419,7 +422,7 @@ def parse_args():
     args = parser.parse_args()
 
     args.gfas = np.array(args.gfas)
-    
+
     return args
 
 
@@ -454,7 +457,7 @@ def main(args=None):
         anis = []
         print("Plotting continuously")
         if args.window is None:
-            gfas.init_continuous_plot()
+            gfas.init_continuous_plot(ignore=args.ignore)
         else:
             gfas.init_continuous_plot(args.window)
         # I cannot explain why I must create a list I will never use to get an
