@@ -33,7 +33,8 @@ def ping(host):
     param = '-n' if platform.system().lower() == 'windows' else '-c'
 
     # Building the command. Ex: "ping -c 1 google.com"
-    command = ['ping', param, '1', "-i", "0.2", host]
+    command = ['ping', param, '1', "-W", "0.5", host]
+    tstart = Time.now()
     x = sub.run(command, stdout=sub.PIPE)
     return x.returncode == 0
 
@@ -62,20 +63,22 @@ def get_key():
     return user_id, org_id, token
 
 
-def get_client(org_id, token):
-    if ping("10.25.1.221"):
-        client = InfluxDBClient(url="http://10.25.1.221:8086", token=token,
-                                org=org_id, timeout=20000)
+def get_client(org_id, token, timeout=20000):
+    if ping("sdss5-webapp.apo.nmsu.edu"):
+        client = InfluxDBClient(url="http://sdss5-webapp.apo.nmsu.edu:9999",
+                                token=token, org=org_id, timeout=timeout)
     else:
         # print("Did not reach 10.25.1.221")
-        client = InfluxDBClient(url="http://localhost:8086", token=token,
-                                org=org_id, timeout=20000)
+        client = InfluxDBClient(url="http://localhost:9999", token=token,
+                                org=org_id, timeout=timeout)
     return client.query_api()
 
 
-def query(flux_script, start, end, interval="1s", verbose=False):
+def query(flux_script, start, end, interval="1s", timeout=20000, verbose=False):
     user, org, token = get_key()
-    client = get_client(org_id=org, token=token)
+    if verbose:
+        print(f"org: {org}, key: {token}")
+    client = get_client(org_id=org, token=token, timeout=timeout)
     query = flux_script
     query = query.replace("v.timeRangeStart", f"{start.isot}Z")
     query = query.replace("v.timeRangeStop", f"{end.isot}Z")
@@ -83,7 +86,7 @@ def query(flux_script, start, end, interval="1s", verbose=False):
     before = Time.now()
     result = client.query(query=query, org=org)
     after = Time.now()
-    if verbose:
+    if verbose >= 1:
         print(query)
         print(f"Query time: {(after - before).sec}s")
     return result
